-- De- bzw. aktiviert und Entfernt FOREIGN-KEY Einschrnkungen
IF EXISTS (SELECT * FROM sysobjects
        WHERE id = OBJECT_ID(N'dbo.spAlterForeignKeys') AND type = 'P')
    DROP PROCEDURE dbo.spAlterForeignKeys
GO
CREATE PROCEDURE dbo.spAlterForeignKeys
(
    @Action       varchar(8) = NULL, -- Aktion
    @TableName    sysname    = NULL  -- Tabellenname (LIKE)
)
AS
/*
 *  Hilfsprozedur zum (De)Aktivieren bzw. Lschen von Foreign Keys
 * (c) Elmar Boye fr SQL Server NG
 * zur freien Verwendungohne jegliche Garantien auf Fehlerfreiheit!!!
 *  Parameter:
 *      Action          CHECK  = FK aktivieren,
 *                          NOCHECK = FK deaktivieren,
 *       DROP = Lschen (irreversibel!)
 *                          sonst Exit
 *  TableName   Name der Tabelle(n) LIKE
 *       NULL = Alle Tabellen, siehe SET im Code
 *
 */
    DECLARE @FKName      sysname
    DECLARE @nCnt           int

    SET NOCOUNT ON

    -- Nur fr db_owner
    IF ISNULL( IS_MEMBER( 'db_owner' ), 0) = 0
    BEGIN
        RAISERROR ('spAlterForeignKeys: Not db_owner.', 16, 1)
        RETURN
    END

 -- Aktionen prfen
    SELECT @Action =
        CASE UPPER(@Action)
        WHEN 'CHECK'   THEN 'CHECK'
        WHEN 'NOCHECK'  THEN 'NOCHECK'
        WHEN 'DROP'  THEN 'DROP'
        ELSE NULL END
    IF @Action IS NULL
        RETURN 1

 -- Default alle (wenn gewnscht)
 SET @TableName = ISNULL(@TableName, '%')

    DECLARE curTable CURSOR
    LOCAL FOR
  SELECT QUOTENAME(USER_NAME(p.uid)) + '.' + QUOTENAME(p.name) AS TableName,
      QUOTENAME(o.name) AS FKName
        FROM sysobjects o INNER JOIN sysobjects p
        ON o.parent_obj = p.id
        WHERE o.type = 'F' AND p.name LIKE @TableName
        ORDER BY p.name, p.uid, o.name, o.uid

    SET @nCnt = 0

    OPEN curTable
    FETCH NEXT FROM curTable INTO @TableName, @FKName
    WHILE (@@fetch_status <> -1)
    BEGIN
        IF (@@fetch_status <> -2)
        BEGIN
            RAISERROR ('%s foreign key %s for table %s', 10, 1,
                @Action, @FKName, @TableName ) WITH NOWAIT
            EXEC ( 'ALTER TABLE ' + @TableName + ' ' + @Action + '
CONSTRAINT ' + @FKName )
            SELECT @nCnt = @nCnt + 1
        END
        FETCH NEXT FROM curTable INTO @TableName, @FKName
    END
    CLOSE curTable
    DEALLOCATE curTable
    RETURN @nCnt
GO